@@ -1,5 +1,4 @@
-
-#' Get NASA POWER Data From the POWER API
+#' Get NASA POWER data from the POWER API
 #'
 #' @description Get \acronym{POWER} global meteorology and surface solar energy
 #'   climatology data and return a tidy data frame [tibble::tibble()]
@@ -9,20 +8,20 @@
 #'   a single point or regional request.  See section on \dQuote{Rate Limiting}
 #'   for more.
 #'
-#' @param community A case-intensive character vector providing community name:
+#' @param community A case-insensitive character vector providing community name:
 #'   \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for more.
-#' @param pars  case-intensive character vector of solar, meteorological or
+#' @param pars  case-insensitive character vector of solar, meteorological or
 #'   climatology parameters to download.  When requesting a single point of x, y
 #'   coordinates, a maximum of twenty (20) `pars` can be specified at one time,
-#'   for \dQuote{DAILY}, \dQuote{MONTHLY} and \dQuote{climatology}
+#'   for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
 #'   `temporal_api`s.  If the `temporal_api` is specified as \dQuote{hourly}
 #'   only 15 `pars` can be specified in a single query.  See `temporal_api` for
 #'   more.  These values are checked internally for validity before sending the
 #'   query to the \acronym{POWER} \acronym{API}.
-#' @param temporal_api A case-intensive character vector providing the temporal
+#' @param temporal_api A case-insensitive character vector providing the temporal
 #'   \acronym{API} end-point for data being queried, supported values are
-#'   \dQuote{hourly}, \dQuote{DAILY}, \dQuote{MONTHLY} or \dQuote{climatology}.
-#'   Defaults to \dQuote{DAILY}.  See argument details for more.
+#'   \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or \dQuote{climatology}.
+#'   Defaults to \dQuote{daily}.  See argument details for more.
 #' @param lonlat A numeric vector of geographic coordinates for a cell or region
 #'   entered as x, y (longitude, latitude) coordinates.  See argument details
 #'   for more.
@@ -36,15 +35,14 @@
 #'   single point of x, y coordinates, not for use with \dQuote{global} or with
 #'   a regional request.
 #' @param wind_elevation A user-supplied value for elevation at a single point
-#'   in metres.  Wind Elevation values in Meters are required to be between 10m
-#'   and 300m.  Only used with `lonlat` as a single point of x, y coordinates,
-#'   not for use with \dQuote{global} or with a regional request.  If this
-#'   parameter is provided, the `wind-surface` parameter is required with the
-#'   request, see
+#'   in metres.  Wind Elevation values are required to be between 10 and 300
+#'   metres.  Only used with `lonlat` as a single point of x, y coordinates, not
+#'   for use with \dQuote{global} or with a regional request.  If this parameter
+#'   is provided, the `wind_surface` parameter is required with the request, see
 #'    <https://power.larc.nasa.gov/docs/methodology/meteorology/wind/>.
 #' @param wind_surface A user-supplied wind surface for which the corrected
 #'   wind-speed is to be supplied.  See `wind-surface` section for more detail.
-#' @param time_standard \acronym{POWER} provides two different time standards:
+#' @param time_standard \acronym{POWER} provides two different time standards.
 #'    * Universal Time Coordinated (\acronym{UTC}): is the standard time measure
 #'     that used by the world.
 #'    * Local Solar Time (\acronym{LST}): A 15 degree swath that represents
@@ -107,7 +105,7 @@
 #'
 #' @section `wind_surface`: There are 17 surfaces that may be used for corrected
 #'   wind-speed values using the following equation:
-#'   \deqn{ WSC_hgt = WS_10m\times(\frac{hgt}{WS_50m})^\alpha}{WSC_hgt = WS_10m*(hgt/WS_50m)^\alpha }
+#'   \deqn{ WSC_hgt = WS_10 m\times(\frac{hgt}{WS_50m})^\alpha}{WSC_hgt = WS_10 m*(hgt/WS_50m)^\alpha }
 #'   Valid surface types are described here.
 #'
 #' \describe{
@@ -146,7 +144,7 @@
 #'
 #' @return A data frame as a `POWER.Info` class, an extension of the
 #' [tibble::tibble], object of \acronym{POWER} data including location, dates
-#' (not including \dQuote{climatology}) and requested parameters.  A decorative
+#' (not including \dQuote{climatology}) and requested parameters; a decorative
 #' header of metadata is included in this object.
 #'
 #' @references
@@ -162,7 +160,7 @@
 #'   lonlat = c(151.81, -27.48),
 #'   pars = c("RH2M", "T2M", "PRECTOTCORR"),
 #'   dates = "1985-01-01",
-#'   temporal_api = "DAILY"
+#'   temporal_api = "daily"
 #' )
 #'
 #' ag_d
@@ -182,7 +180,7 @@
 #'   community = "RE",
 #'   lonlat = c(112.5, -55.5, 115.5, -50.5),
 #'   dates = c("1984", "1985"),
-#'   temporal_api = "MOHTHLY",
+#'   temporal_api = "monthly",
 #'   pars = c("CLRSKY_SFC_SW_DWN", "ALLSKY_SFC_SW_DWN")
 #' )
 #'
@@ -193,10 +191,7 @@
 #' @export
 get_power <- function(community = c("ag", "re", "sb"),
                       pars,
-                      temporal_api = c("daily",
-                                       "monthly",
-                                       "hourly",
-                                       "climatology"),
+                      temporal_api = c("daily", "monthly", "hourly", "climatology"),
                       lonlat,
                       dates = NULL,
                       site_elevation = NULL,
@@ -217,102 +212,26 @@ get_power <- function(community = c("ag", "re", "sb"),
     dates <- NULL
   }
 
-  if (any(tolower(lonlat) == "global")) {
-    # remove this if POWER enables global queries for climatology again
-    cli::cli_abort(
-      c(x = "The POWER team have not enabled {.var global} data queries with
-        this version of the 'API'.")
-    )
-  }
-  if (!is.null(site_elevation) && !is.numeric(site_elevation)) {
-    cli::cli_abort(
-      c(x = "You have entered an invalid value for {.arg site_elevation},
-         {.val site_elevation}.")
-    )
-  }
-  if (length(lonlat) > 2 && !is.null(site_elevation)) {
-    cli::cli_inform(
-      c(
-        x = "You have provided {.arg site_elevation}, {.var {site_elevation}}
-        for a region request. The {.arg site_elevation} value will be ignored."
-      )
-    )
-    site_elevation <- NULL
-  }
-
-  if (length(lonlat) > 2 && !is.null(wind_elevation)) {
-    cli::cli_inform(
-      c(
-      "You have provided {.arg wind_elevation}, {.var {wind_elevation}},
-      for a region request.",
-      i = "The {.arg wind_elevation} value will be ignored."
-      )
-    )
-    wind_elevation <- NULL
-  }
-
-  if (is.character(wind_surface) && is.null(wind_elevation)) {
-    cli::cli_abort(
-      c(
-        x = "If you provide a correct wind surface alias, {.arg wind_surface},
-        please include a surface elevation, {.arg wind_elevation}, with the
-        request."
-      )
-    )
-  }
-  if (!is.null(wind_elevation)) {
-    if (wind_elevation < 10 || wind_elevation > 300) {
-      cli::cli_abort(
-        c(x = "{.arg wind_elevation} values in metres are required to be between
-          10m and 300m.")
-      )
-    }
-  }
-  if (is.character(lonlat)) {
-    lonlat <- tolower(lonlat)
-    if (lonlat != "global") {
-      cli::cli_abort(
-        c(
-          x = "You have entered an invalid value for {.arg lonlat}.",
-          i = "Valid values are {.val global} with {.val climatology}",
-          "or a string of lon and lat values."
-        )
-      )
-    }
-  }
-
-  if (temporal_api == "hourly" && length(lonlat) == 4L) {
-    cli::cli_abort(c(x = "{.arg temporal_api} does not support hourly values for
-                     regional queries."))
-  }
-
-  if (length(pars) > 15 && temporal_api == "hourly") {
-    cli::cli_abort(
-      call = rlang::caller_env(),
-      c(x = "A maximum of 15 parameters can currently be requested in one
-        submission for hourly data.",
-        i = "You have submitted {.val {length(pars)}}")
-    )
-  } else if (length(pars) > 20) {
-    cli::cli_abort(
-      call = rlang::caller_env(),
-      c(i = "A maximum of 20 parameters can currently be requested in one
-        submission.",
-        i = "You have submitted {.val {length(pars)}}")
-    )
-  }
-
+  # check user inputs for validity ---------------------------------------------
   # see internal_functions.R for these functions prefixed with "."
-  pars <- .check_pars(pars = pars,
-                      community = community,
-                      temporal_api = temporal_api)
-  lonlat_identifier <- .check_lonlat(lonlat,
-                                     pars)
-  dates <- .check_dates(dates,
-                        lonlat,
-                        temporal_api)
+  .check_inputs(
+    lonlat = lonlat,
+    pars = pars,
+    site_elevation = site_elevation,
+    temporal_api = temporal_api,
+    wind_elevation = wind_elevation,
+    wind_surface = wind_surface
+  )
 
-  # submit query -------------------------------------------------------------
+  pars <- .check_pars(
+    pars = pars,
+    community = community,
+    temporal_api = temporal_api
+  )
+  lonlat_identifier <- .check_lonlat(lonlat, pars)
+  dates <- .check_dates(dates, lonlat, temporal_api)
+
+  # submit query ---------------------------------------------------------------
   query_list <- .build_query(
     community,
     lonlat_identifier,
@@ -331,25 +250,25 @@ get_power <- function(community = c("ag", "re", "sb"),
   )
 
   response <-
-    .send_query(.query_list = query_list,
-                .url = power_url)
+    .send_query(.query_list = query_list, .url = power_url)
 
   response$raise_for_status()
 
+  # extract query results and return to user -----------------------------------
   # create meta object
   power_data <- readr::read_lines(I(response$parse("UTF8")))
 
-  meta <- power_data[c(grep("-BEGIN HEADER-",
-                            power_data):grep("-END HEADER-",
-                                             power_data))]
+  meta <- power_data[c(grep("-BEGIN HEADER-", power_data):grep("-END HEADER-", power_data))]
   # strip BEGIN/END HEADER lines
   meta <- meta[-c(1, max(length(meta)))]
 
   # replace missing values with NA in metadata header
   for (i in c("-999", "-99", "-99.00")) {
-    meta <- gsub(pattern = i,
-                 replacement = "NA",
-                 x = meta)
+    meta <- gsub(
+      pattern = i,
+      replacement = "NA",
+      x = meta
+    )
   }
 
   # create tibble object
@@ -370,19 +289,17 @@ get_power <- function(community = c("ag", "re", "sb"),
 
   # if the temporal average is anything but climatology, add date fields
   if (temporal_api == "daily" &&
-      query_list$community == "re" ||
-      query_list$community == "sb") {
+    query_list$community == "re" ||
+    query_list$community == "sb") {
     power_data <- .format_dates_re_sb(power_data)
   }
   if (temporal_api == "daily" &&
-      query_list$community == "ag") {
+    query_list$community == "ag") {
     power_data <- .format_dates_ag(power_data)
   }
 
   # add new class
-  power_data <- tibble::new_tibble(power_data,
-                                   class = "POWER.Info",
-                                   nrow = nrow(power_data))
+  power_data <- tibble::new_tibble(power_data, class = "POWER.Info", nrow = nrow(power_data))
 
   # add attributes for printing df
   attr(power_data, "POWER.Info") <- meta[1]
@@ -392,14 +309,13 @@ get_power <- function(community = c("ag", "re", "sb"),
   attr(power_data, "POWER.Climate_zone") <- meta[5]
   attr(power_data, "POWER.Missing_value") <- meta[6]
   attr(power_data, "POWER.Parameters") <-
-    paste(meta[7:length(meta)],
-          collapse = ";\n ")
+    paste(meta[7:length(meta)], collapse = ";\n ")
   return(power_data)
 }
 
-# functions internal to get_power() -----
+# subfunctions internal to get_power() -----------------------------------------
 
-#' Check Dates for Validity When Querying API
+#' Check dates for validity when querying the API
 #'
 #' Validates user entered dates against `lonlat` and `temporal_api` values
 #'
@@ -407,13 +323,14 @@ get_power <- function(community = c("ag", "re", "sb"),
 #' @param lonlat User entered `lonlat` value.
 #' @param temporal_api User entered `temporal_api` value.
 #'
-#' @return Validated dates in a list for use in `.build_query`
+#' @return Validated dates in a list for use in `.build_query`.
 #' @keywords internal
 #' @noRd
 .check_dates <- function(dates, lonlat, temporal_api) {
   if (is.null(dates) & temporal_api != "climatology") {
     cli::cli_abort(c(i = "You have not entered dates for the query."),
-                   call = rlang::caller_env())
+      call = rlang::caller_env()
+    )
   }
   if (temporal_api == "monthly") {
     if (length(unique(dates)) < 2) {
@@ -436,90 +353,217 @@ get_power <- function(community = c("ag", "re", "sb"),
     return(dates)
   }
   if (temporal_api == "daily" || temporal_api == "hourly") {
-    if (is.numeric(lonlat)) {
-      if (length(dates) == 1) {
-        dates <- c(dates, dates)
-      }
-      if (length(dates) > 2) {
-        cli::cli_abort(
-          c(
-            i = "You have supplied more than two dates for start and end.",
-            x = "Please supply only two (2) dates for {.arg dates} as
-            'YYYY-MM-DD' (ISO8601 format)."
-          ),
-          call = rlang::caller_env()
-        )
-      }
-
-      # put dates in list to use lapply
-      dates <- as.list(dates)
-
-      # check dates as entered by user
-      date_format <- function(x) {
-        rlang::try_fetch(
-          # try to parse the date format using lubridate
-          x <- lubridate::parse_date_time(x,
-                                          c(
-                                            "Ymd",
-                                            "dmY",
-                                            "mdY",
-                                            "BdY",
-                                            "Bdy",
-                                            "bdY",
-                                            "bdy"
-                                          )),
-          warning = function(c) {
-            cli::cli_abort(
-              call = rlang::caller_env(),
-              c(i = "{.var {x}} is not a valid entry for a date value.",
-                x = "Enter as 'YYYY-MM-DD' (ISO8601 format) and check that it
-                is a valid date.")
-            )
-          }
-        )
-        as.Date(x)
-      }
-
-      # apply function to reformat/check dates
-      dates <- lapply(X = dates, FUN = date_format)
-
-      # if the stdate is > endate, flip order
-      if (dates[[2]] < dates[[1]]) {
-        cli::cli_alert_info(c(i = "Your start and end dates were reversed.
-                              They have been reordered."))
-        dates <- c(dates[2], dates[1])
-      }
-
-      # check date to be sure it's not before POWER data start
-      if (temporal_api != "hourly" &&
-          dates[[1]] < "1981-01-01") {
-        cli::cli_abort(
-          call = rlang::caller_env(),
-          c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.",
-            x = "1981-01-01 is the earliest available data from POWER.")
-        )
-      } else if (temporal_api == "hourly" &
-                 dates[[1]] < "2001-01-01")
-        cli::cli_abort(
-          call = rlang::caller_env(),
-          c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.",
-            x = "2001-01-01 is the earliest available hourly data from POWER.")
-        )
-      # check end date to be sure it's not _after_
-      if (dates[[2]] > Sys.Date()) {
-        cli::cli_abort(
-          call = rlang::caller_env(),
-          c(i = "{.arg dates} = {.val {dates[[2]]}} is invalid.",
-            x = "The weather data cannot possibly extend beyond this day.")
-        )
-      }
-
-      dates <- lapply(dates, as.character)
-      dates <- gsub("-", "", dates, ignore.case = TRUE)
+    if (is.numeric(lonlat) && length(dates) == 1) {
+      dates <- c(dates, dates)
     }
+    if (length(dates) > 2) {
+      cli::cli_abort(
+        c(
+          i = "You have supplied more than two dates for start and end.",
+          x = "Please supply only two (2) dates for {.arg dates} as
+            'YYYY-MM-DD' (ISO8601 format)."
+        ),
+        call = rlang::caller_env()
+      )
+    }
+
+    # put dates in list to use lapply
+    dates <- as.list(dates)
+
+    # check dates as entered by user
+    date_format <- function(x) {
+      rlang::try_fetch(
+        # try to parse the date format using lubridate
+        x <- lubridate::parse_date_time(x, c(
+          "Ymd", "dmY", "mdY", "BdY", "Bdy", "bdY", "bdy"
+        )),
+        warning = function(c) {
+          cli::cli_abort(
+            call = rlang::caller_env(),
+            c(i = "{.var {x}} is not a valid entry for a date value.", x = "Enter as 'YYYY-MM-DD' (ISO8601 format) and check that it
+                is a valid date.")
+          )
+        }
+      )
+      as.Date(x)
+    }
+
+    # apply function to reformat/check dates
+    dates <- lapply(X = dates, FUN = date_format)
+
+    # if the stdate is > endate, flip order
+    if (dates[[2]] < dates[[1]]) {
+      cli::cli_alert_info(c(i = "Your start and end dates were reversed.
+                              They have been reordered."))
+      dates <- c(dates[2], dates[1])
+    }
+
+    # check date to be sure it's not before POWER data start
+    if (temporal_api != "hourly" &&
+      dates[[1]] < "1981-01-01") {
+      cli::cli_abort(
+        call = rlang::caller_env(),
+        c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.", x = "1981-01-01 is the earliest available data from POWER.")
+      )
+    } else if (temporal_api == "hourly" &
+      dates[[1]] < "2001-01-01") {
+      cli::cli_abort(
+        call = rlang::caller_env(),
+        c(i = "{.arg dates} = {.val {dates[[1]]}} is an invalid value.", x = "2001-01-01 is the earliest available hourly data from POWER.")
+      )
+    }
+    # check end date to be sure it's not _after_
+    if (dates[[2]] > Sys.Date()) {
+      cli::cli_abort(
+        call = rlang::caller_env(),
+        c(i = "{.arg dates} = {.val {dates[[2]]}} is invalid.", x = "The weather data cannot possibly extend beyond this day.")
+      )
+    }
+
+    dates <- lapply(dates, as.character)
+    dates <- gsub("-", "", dates, ignore.case = TRUE)
   }
 }
 
+#' Check User Inputs for get_power for Validity
+#' @param community A case-insensitive character vector providing community name:
+#'   \dQuote{AG}, \dQuote{RE} or \dQuote{SB}.  See argument details for more.
+#' @param pars  case-insensitive character vector of solar, meteorological or
+#'   climatology parameters to download.  When requesting a single point of x, y
+#'   coordinates, a maximum of twenty (20) `pars` can be specified at one time,
+#'   for \dQuote{daily}, \dQuote{monthly} and \dQuote{climatology}
+#'   `temporal_api`s.  If the `temporal_api` is specified as \dQuote{hourly}
+#'   only 15 `pars` can be specified in a single query.  See `temporal_api` for
+#'   more.  These values are checked internally for validity before sending the
+#'   query to the \acronym{POWER} \acronym{API}.
+#' @param temporal_api A case-insensitive character vector providing the temporal
+#'   \acronym{API} end-point for data being queried, supported values are
+#'   \dQuote{hourly}, \dQuote{daily}, \dQuote{monthly} or \dQuote{climatology}.
+#'   Defaults to \dQuote{daily}.  See argument details for more.
+#' @param lonlat A numeric vector of geographic coordinates for a cell or region
+#'   entered as x, y (longitude, latitude) coordinates.  See argument details
+#'   for more.
+#' @param site_elevation A user-supplied value for elevation at a single point
+#'   in metres.  If provided this will return a corrected atmospheric pressure
+#'   value adjusted to the elevation provided.  Only used with `lonlat` as a
+#'   single point of x, y coordinates, not for use with \dQuote{global} or with
+#'   a regional request.
+#' @param wind_elevation A user-supplied value for elevation at a single point
+#'   in metres.  Wind Elevation values in Meters are required to be between 10 m
+#'   and 300 m.  Only used with `lonlat` as a single point of x, y coordinates,
+#'   not for use with \dQuote{global} or with a regional request.  If this
+#'   parameter is provided, the `wind_surface` parameter is required with the
+#'   request, see
+#'    <https://power.larc.nasa.gov/docs/methodology/meteorology/wind/>.
+#' @param wind_surface A user-supplied wind surface for which the corrected
+#'   wind-speed is to be supplied.  See `wind-surface` section for more detail.
+#' @return Nothing, called for its side-effects of checking user inputs.
+#' @keywords Internal
+#' @noRd
+
+.check_inputs <- function(community,
+                          lonlat,
+                          pars,
+                          site_elevation,
+                          temporal_api,
+                          wind_elevation,
+                          wind_surface) {
+  if (any(tolower(lonlat) == "global")) {
+    # remove this if POWER enables global queries for climatology again
+    cli::cli_abort(
+      c(x = "The POWER team have not enabled {.var global} data queries with
+        this version of the 'API'."),
+      call = rlang::caller_env()
+    )
+  }
+  if (!is.null(site_elevation) && !is.numeric(site_elevation)) {
+    cli::cli_abort(
+      c(x = "You have entered an invalid value for {.arg site_elevation},
+         {.val site_elevation}."),
+      call = rlang::caller_env()
+    )
+  }
+  if (length(lonlat) > 2 && !is.null(site_elevation)) {
+    cli::cli_inform(
+      c(
+        x = "You have provided {.arg site_elevation}, {.var {site_elevation}}
+        for a region request. The {.arg site_elevation} value will be ignored."
+      ),
+      call = rlang::caller_env()
+    )
+    site_elevation <- NULL
+  }
+
+  if (length(lonlat) > 2 && !is.null(wind_elevation)) {
+    cli::cli_inform(
+      c(
+        "You have provided {.arg wind_elevation}, {.var {wind_elevation}},
+      for a region request.",
+        i = "The {.arg wind_elevation} value will be ignored."
+      ),
+      call = rlang::caller_env()
+    )
+    wind_elevation <- NULL
+  }
+
+  if (is.character(wind_surface) && is.null(wind_elevation)) {
+    cli::cli_abort(
+      c(
+        x = "If you provide a correct wind surface alias, {.arg wind_surface},
+        please include a surface elevation, {.arg wind_elevation}, with the
+        request."
+      ),
+      call = rlang::caller_env()
+    )
+  }
+
+  if (!is.null(wind_elevation) && (!is.numeric(wind_elevation) ||
+    (wind_elevation %notin% 10:300))) {
+    cli::cli_abort(
+      c(x = "{.arg wind_elevation} values in metres are required to be between
+          10 and 300 metres inclusive."),
+      call = rlang::caller_env()
+    )
+  }
+
+  if (is.character(lonlat)) {
+    lonlat <- tolower(lonlat)
+    if (lonlat != "global") {
+      cli::cli_abort(
+        c(
+          x = "You have entered an invalid value for {.arg lonlat}.",
+          i = "Valid values are {.val global} with {.val climatology}",
+          "or a string of lon and lat values."
+        ),
+        call = rlang::caller_env()
+      )
+    }
+  }
+
+  if (temporal_api == "hourly" && length(lonlat) == 4L) {
+    cli::cli_abort(
+      c(x = "{.arg temporal_api} does not support hourly values for
+                     regional queries."),
+      call = rlang::caller_env()
+    )
+  }
+
+  if (length(pars) > 15 && temporal_api == "hourly") {
+    cli::cli_abort(
+      call = rlang::caller_env(),
+      c(x = "A maximum of 15 parameters can currently be requested in one
+        submission for hourly data.", i = "You have submitted {.val {length(pars)}}"),
+    )
+  } else if (length(pars) > 20) {
+    cli::cli_abort(
+      call = rlang::caller_env(),
+      c(x = "A maximum of 20 parameters can currently be requested in one
+        submission.", i = "You have submitted {.val {length(pars)}}")
+    )
+  }
+}
+
+
 #' Check user-supplied `lonlat` for validity when querying API
 #'
 #' Validates user entered `lonlat` values and checks against `pars`
@@ -528,7 +572,7 @@ get_power <- function(community = c("ag", "re", "sb"),
 #' @param lonlat User entered `lonlat` value.
 #' @param pars User entered `pars` value.
 #'
-#' @return A list called `lonlat_identifier` for use in [.build_query()]
+#' @return A list called `lonlat_identifier` for use in [.build_query()].
 #' @keywords internal
 #' @noRd
 .check_lonlat <-
@@ -538,8 +582,10 @@ get_power <- function(community = c("ag", "re", "sb"),
       if (lonlat == "global") {
         identifier <- "global"
       } else if (is.character(lonlat)) {
-        cli::cli_abort(call = rlang::caller_env(),
-                       c(i = "You have entered an invalid request for `lonlat`."))
+        cli::cli_abort(
+          call = rlang::caller_env(),
+          c(i = "You have entered an invalid request for `lonlat`.")
+        )
       }
     } else if (is.numeric(lonlat) & length(lonlat) == 2) {
       if (lonlat[1] < -180 | lonlat[1] > 180) {
@@ -550,7 +596,7 @@ get_power <- function(community = c("ag", "re", "sb"),
         )
       }
       if (lonlat[2] < -90 |
-          lonlat[2] > 90) {
+        lonlat[2] > 90) {
         cli::cli_abort(
           call = rlang::caller_env(),
           c(i = "Please check your latitude, {.val {lonlat[2]}},
@@ -571,18 +617,18 @@ get_power <- function(community = c("ag", "re", "sb"),
           )
         )
       } else if (any(lonlat[1] < -180 |
-                     lonlat[3] < -180 |
-                     lonlat[1] > 180 |
-                     lonlat[3] > 180)) {
+        lonlat[3] < -180 |
+        lonlat[1] > 180 |
+        lonlat[3] > 180)) {
         cli::cli_abort(
           call = rlang::caller_env(),
           c(i = "Please check your longitude values, {.var {lonlat[1]}} and
             {.var {lonlat[3]}}, to be sure they are valid.")
         )
       } else if (any(lonlat[2] < -90 |
-                     lonlat[4] < -90 |
-                     lonlat[2] > 90 |
-                     lonlat[4] > 90)) {
+        lonlat[4] < -90 |
+        lonlat[2] > 90 |
+        lonlat[4] > 90)) {
         cli::cli_abort(
           call = rlang::caller_env(),
           c(i = "Please check your latitude values, {.var {lonlat[2]}} and
@@ -591,14 +637,12 @@ get_power <- function(community = c("ag", "re", "sb"),
       } else if (lonlat[2] > lonlat[4]) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(
-            i = "The first `lonlat` {.arg lat} value must be the minimum value.")
+          c(i = "The first `lonlat` {.arg lat} value must be the minimum value.")
         )
       } else if (lonlat[1] > lonlat[3]) {
         cli::cli_abort(
           call = rlang::caller_env(),
-          c(
-            i = "The first `lonlat` {.arg lon} value must be the minimum value.")
+          c(i = "The first `lonlat` {.arg lon} value must be the minimum value.")
         )
       }
       identifier <- "regional"
@@ -612,7 +656,8 @@ get_power <- function(community = c("ag", "re", "sb"),
       cli::cli_abort(
         call = rlang::caller_env(),
         c(i = "You have entered an invalid request for `lonlat`
-          {.arg {lonlat}}."))
+          {.arg {lonlat}}.")
+      )
     }
 
     if (!is.null(bbox)) {
@@ -632,14 +677,14 @@ get_power <- function(community = c("ag", "re", "sb"),
 #' Construct a list of options to pass to the POWER API
 #'
 #' @param community A validated value for community from [check_community()].
-#' @param lonlat_identifier A list of values, a result of [check_lonlat()]
+#' @param lonlat_identifier A list of values, a result of [check_lonlat()].
 #' @param pars A validated value from [check_pars()].
-#' @param dates A list of values, a result of [check_dates()].
-#' @param site_elevation A validated value from
-#' @param wind_elevation A validate value from
-#' @param wind_surface A validated value from
+#' @param dates A list of values, a result of [check_dates()]..
+#' @param site_elevation A validated value passed by `check_inputs`.
+#' @param wind_elevation A validated value passed by `check_inputs`.
+#' @param wind_surface A validated value passed by `check_inputs`.
 #' @return A `list` object of values to be passed to a [crul] object to query
-#'  the 'POWER' 'API'
+#'  the 'POWER' 'API'.
 #' @keywords internal
 #' @noRd
 .build_query <- function(community,
@@ -715,25 +760,19 @@ get_power <- function(community = c("ag", "re", "sb"),
   # Calculate the full date from YEAR and DOY
   power_response <- tibble::add_column(
     power_response,
-    YYYYMMDD = as.Date(power_response$DOY - 1,
-                       origin = as.Date(
-                         paste(power_response$YEAR, "-01-01",
-                               sep = "")
-                       )),
+    YYYYMMDD = as.Date(power_response$DOY - 1, origin = as.Date(paste0(
+      power_response$YEAR, "-01-01"
+    ))),
     .after = "DOY"
   )
 
   # Extract month as integer
-  power_response <- tibble::add_column(power_response,
-                                       MM = as.integer(substr(power_response$YYYYMMDD, 6, 7)),
-                                       .after = "YEAR")
+  power_response <- tibble::add_column(power_response, MM = as.integer(substr(power_response$YYYYMMDD, 6, 7)), .after = "YEAR")
 
   # Extract day as integer
-  return(tibble::add_column(power_response,
-                            DD = as.integer(substr(
-                              power_response$YYYYMMDD, 9, 10
-                            )),
-                            .after = "MM"))
+  return(tibble::add_column(power_response, DD = as.integer(substr(
+    power_response$YYYYMMDD, 9, 10
+  )), .after = "MM"))
 }
 
 #' Format date columns in POWER data frame for the re community
